@@ -7,6 +7,7 @@ from ...models.utils.types.serializer_type import SerializerType
 import logging
 import json
 from datetime import datetime
+from zoneinfo import ZoneInfo
 # Create and configure logger
 logger = logging.getLogger("chatty_asset_model")
 
@@ -36,6 +37,16 @@ class ChattyAssetPreview(TimestampValidationMixin, BaseModel):
             "company_id": 1
         }
 
+    @classmethod
+    def not_found(cls, id: StrObjectId, company_id: StrObjectId) -> 'ChattyAssetPreview':
+        return cls(
+            _id=id,
+            name=f"Not found {id}",
+            company_id=company_id,
+            created_at=datetime.now(tz=ZoneInfo("UTC")),
+            updated_at=datetime.now(tz=ZoneInfo("UTC"))
+        )
+
     @classmethod
     def from_dict(cls, data: dict) -> 'ChattyAssetPreview':
         return cls(**data)
