@@ -2,4 +2,7 @@ from pydantic import BaseModel
 
 class ChattyContentText(BaseModel):
     body: str 
-    preview_url: bool = False
\ No newline at end of file
+    preview_url: bool = False
+    
+    def get_body_or_caption(self) -> str:
+        return self.body
\ No newline at end of file
