@@ -517,7 +517,7 @@ class ChatService:
         Desassign a chat from an agent.
         """
         if chat.area != Area.WITH_AGENT:
-            raise ValueError(f"Chat {chat.id} is not assigned to an agent")
+            raise AlreadyCompleted(f"Chat {chat.id} is already not assigned to any agent")
         if current_agent.id == execution_context.executor.id:
             ChatService.add_central_notification_from_text(chat=chat, body=f"El chat fue desasignado por {execution_context.executor.name}", subtype=MessageSubtype.CHAT_DESASSIGNED)
         else: #notify the previous agent
